#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   alsa-core
version:                0.5.0.1
visibility:             public
id:                     alsa-core-0.5.0.1-DS67XwizAMDDx6BMv2E7yf
key:                    alsa-core-0.5.0.1-DS67XwizAMDDx6BMv2E7yf
license:                BSD-3-Clause
copyright:              Bjorn Bringert, Iavor S. Diatchki, Henning Thielemann
maintainer:             Henning Thielemann <alsa@henning-thielemann.de>
author:
    Henning Thielemann <alsa@henning-thielemann.de>, Bjorn Bringert <bjorn@bringert.net>, Iavor S. Diatchki <iavor.diatchki@gmail.com>

stability:              Experimental
homepage:               http://www.haskell.org/haskellwiki/ALSA
synopsis:               Binding to the ALSA Library API (Exceptions).
description:
    This package provides access to ALSA infrastructure,
    that is needed by both alsa-seq and alsa-pcm.

category:               Sound, Music
abi:                    40b69d99ea427860fef14dd9c33ef5a4
exposed:                True
exposed-modules:        Sound.ALSA.Exception
import-dirs:            /usr/lib/ghc-9.6.6/site-local/alsa-core-0.5.0.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/alsa-core-0.5.0.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/alsa-core-0.5.0.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-alsa-core
hs-libraries:           HSalsa-core-0.5.0.1-DS67XwizAMDDx6BMv2E7yf
extra-libraries:        asound
extra-libraries-static: asound m pthread rt
include-dirs:           /usr/include
depends:
    base-4.18.2.1 extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH

haddock-interfaces:     /usr/share/doc/haskell-alsa-core/html/alsa-core.haddock
haddock-html:           /usr/share/doc/haskell-alsa-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

